Learn R Programming

IsingSampler (version 0.5.0)

IsingLikelihood: Likelihood of all states from tractible Ising model.

Description

This function returns the likelihood of all possible states. Is only tractible up to rougly 10 nodes.

Usage

IsingLikelihood(graph, thresholds, beta, responses = c(0L, 1L),
                 potential = FALSE, delta = 0)

Arguments

graph

Square matrix indicating the weights of the network. Must be symmetrical with 0 as diagonal.

thresholds

Vector indicating the thresholds, also known as the external field.

beta

Scalar indicating the inverse temperature.

responses

Response options. Typically set to c(-1L, 1L) or c(0L, 1L) (default). Two or more numeric response options are supported, including non-integer values such as seq(-1, 1, by = 0.5).

potential

Logical, return the potential instead of the probability of each state?

delta

Optional per-node quadratic (Blume-Capel) term added to the Hamiltonian as delta_i * s_i^2; a single value (recycled over nodes) or one value per node. The default 0 corresponds to the ordinary Ising model. See BlumeCapelSampler.

Author

Sacha Epskamp