This function returns the likelihood of all possible states. Is only tractible up to rougly 10 nodes.
IsingLikelihood(graph, thresholds, beta, responses = c(0L, 1L),
potential = FALSE, delta = 0)
Square matrix indicating the weights of the network. Must be symmetrical with 0 as diagonal.
Vector indicating the thresholds, also known as the external field.
Scalar indicating the inverse temperature.
Response options. Typically set to c(-1L, 1L) or c(0L, 1L) (default). Two or more numeric response options are supported, including non-integer values such as seq(-1, 1, by = 0.5).
Logical, return the potential instead of the probability of each state?
Optional per-node quadratic (Blume-Capel) term added to the Hamiltonian as delta_i * s_i^2; a single value (recycled over nodes) or one value per node. The default 0 corresponds to the ordinary Ising model. See BlumeCapelSampler.
Sacha Epskamp